import { DynamoDBClient } from "@aws-sdk/client-dynamodb";
import { DynamoDBDocumentClient } from "@aws-sdk/lib-dynamodb";
import { Logger } from "@aws-sdk/types";
type Put = {
    item: Record<string, any>;
};
type Update = {
    item: Record<string, any>;
    key: Record<string, any>;
};
type Increment = {
    field: string;
    key: Record<string, any>;
    step?: number;
};
type Query<Type> = {
    key: Record<string, any>;
    indexName?: string;
    query?: Record<string, any>;
    limit?: number;
    scanIndexForward?: boolean;
    exclusiveStartKey?: Record<string, string>;
    recursive?: boolean;
    items?: Type[];
    filterDeleted?: boolean;
};
type Get = {
    key: Record<string, any>;
};
type BatchGet = {
    keys: Record<string, string>[];
};
type Scan<Type> = {
    exclusiveStartKey?: Record<string, string>;
    query?: Record<string, any>;
    recursive?: boolean;
    items?: Type[];
    filterDeleted?: boolean;
};
type Delete = {
    key: Record<string, any>;
    soft?: boolean;
};
export declare const buildFilterExpression: (input?: Record<string, unknown>) => string | undefined;
export type DinamoConfig = {
    endpoint?: string;
    logger?: Logger;
    region?: string;
    tableName: string;
};
export default class Dinamo {
    client: DynamoDBClient;
    dynamoDB: DynamoDBDocumentClient;
    tableName: string;
    constructor(config: DinamoConfig);
    batchGet<Type>({ keys }: BatchGet): Promise<Type[]>;
    decrement<Type>({ key, field, step }: Increment): Promise<Type>;
    delete<Type>({ key, soft }: Delete): Promise<import("@aws-sdk/lib-dynamodb").DeleteCommandOutput | Type>;
    get<Type>({ key }: Get): Promise<Type>;
    increment<Type>({ key, field, step }: Increment): Promise<Type>;
    put({ item }: Put): Promise<import("@aws-sdk/lib-dynamodb").PutCommandOutput>;
    query<Type>({ indexName, key, limit, query: input, scanIndexForward, exclusiveStartKey, items, recursive, filterDeleted, }: Query<Type>): Promise<{
        data: Type[];
        lastEvaluatedKey?: Record<string, string>;
    }>;
    scan<Type>({ exclusiveStartKey, items, query, recursive, filterDeleted, }: Scan<Type>): Promise<{
        data: Type[];
        lastEvaluatedKey?: Record<string, string>;
    }>;
    update<Type>({ key, item }: Update): Promise<Type>;
}
export {};
//# sourceMappingURL=index.d.ts.map